RCDBError

Enum RCDBError 

pub enum RCDBError {
    SqliteError(Error),
    ConditionTypeNotFound(String),
    MissingSchemaVersion,
    EmptyConditionList,
    PathResolutionError(Error),
    GlueXCoreError(GlueXCoreError),
    UnknownValueType(String),
    ConditionTypeMismatch {
        condition_name: String,
        expected: ValueType,
        actual: ValueType,
    },
    MissingTimeValue {
        condition_name: String,
        run_number: RunNumber,
    },
    MissingConnectionEnv(String),
}
Errors that can occur while interacting with RCDB metadata or payloads.

Variants



SqliteError(Error)

Wrapper around rusqlite::Error.



ConditionTypeNotFound(String)

Requested condition name does not exist.



MissingSchemaVersion

The SQLite file does not contain the expected schema version entry.



EmptyConditionList

Fetch API requires at least one condition name.



PathResolutionError(Error)

Failed to resolve or canonicalize a filesystem path.



GlueXCoreError(GlueXCoreError)

Timestamp parsing failed while decoding a time condition.



UnknownValueType(String)

Encountered a value type identifier we do not understand.



ConditionTypeMismatch

Predicate requested a condition with a mismatched type.

Fields

condition_name: String

Name of the offending condition.

expected: ValueType

Type requested by the predicate builder.

actual: ValueType

Type stored in the database schema.



MissingTimeValue

time condition row was missing a time_value entry.

Fields

condition_name: String

Name of the time-valued condition.

run_number: RunNumber

Run number missing the time value.



MissingConnectionEnv(String)

Required environment variable is not set.