RunSelection

Enum RunSelection 

pub enum RunSelection {
    All,
    Runs(Vec<RunNumber>),
    Range {
        start: RunNumber,
        end: RunNumber,
    },
}
Describes how runs should be selected when fetching condition values.

Variants



All

Return conditions for every run stored in RCDB.



Runs(Vec<RunNumber>)

Return conditions only for the exact run numbers in the list.



Range

Return conditions for every run within the inclusive range.

Fields

start: RunNumber

Inclusive start run number.

end: RunNumber

Inclusive end run number.

Implementations

Source

impl RunSelection

pub fn is_empty(&self) -> bool

True when no runs will be returned.